<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateSQRLTables extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::connection(config('sqrl.database'))->create('pubkeys',function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->timestamps();

            $table->string('public_key')->unique();
            $table->string('vuk');
            $table->string('suk');
            $table->tinyInteger('disabled')->default(0);
            $table->tinyInteger('sqrl_only_allowed')->default(0);
            $table->tinyInteger('hardlock')->default(0);
        });

        Schema::connection(config('sqrl.database'))->create('nonces',function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->timestamps();

            $table->string('nonce')->unique();
            $table->enum('type', ['auth', 'question']);
            $table->ipAddress('ip');
            $table->longText('url');
            $table->longText('can');
            $table->tinyInteger('verified')->default(0);
            $table->longText('question')->nullable();
            $table->tinyInteger('btn_answer')->nullable();
            $table->string('orig_nonce')->nullable();

            $table->bigInteger('pubkey_id')->unsigned()->nullable();
            $table->foreign('pubkey_id')->references('id')->on('pubkeys')->onDelete('cascade');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::connection($this->connection)->dropIfExists('nonces');
        Schema::connection($this->connection)->dropIfExists('pubkeys');
    }
}
